import { BasicColumn, FormSchema } from '@/components/Table';

export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 120,
    // slots: { customRender: 'name' },
  },
  {
    title: '场景',
    dataIndex: 'scene',
    width: 150,
  },
  {
    title: '权属工作组',
    dataIndex: 'workgroup',
    width: 120,
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 150,
  },
  {
    title: '更新时间',
    dataIndex: 'updateTime',
    width: 150,
  },
  {
    title: '拥有者',
    dataIndex: 'owner',
    width: 100,
  },
  {
    title: '发布状态',
    dataIndex: 'releaseStatus',
    width: 120,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    colProps: { span: 5 },
    componentProps: {
      placeholder: '输入关键字搜索',
    },
  },
  {
    field: 'releaseStatus',
    label: ' ',
    component: 'Select',
    colProps: { span: 5 },
    componentProps: {
      placeholder: '发布状态',
      options: [
        { label: '未发布', value: '未发布' },
        { label: '已发布', value: '已发布' },
        { label: '审核中', value: '审核中' },
        { label: '已下线', value: '已下线' },
      ],
    },
  },
];
export const importFormSchema: any[] = [
  {
    label: '导入任务版本',
    field: 'importVersionAlert',
    slot: 'importVersionAlert',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'importType',
    label: '导入类型',
    component: 'RadioGroup',
    required: true,
    colProps: { lg: 24, md: 24 },
    defaultValue: '1',
    componentProps: {
      options: [
        { label: '同集群导入', value: '1' },
        { label: '其他集群导入', value: '2' },
      ],
    },
  },
  {
    field: 'importOptionsAlert',
    slot: 'importOptionsAlert',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'deptId',
    label: '导入至',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'deptName',
        value: 'businessId',
      },
      treeData: [
        {
          deptName: '数据加载',
          businessId: '1',
          children: [
            {
              deptName: '个人工作区',
              businessId: '11',
              children: [
                {
                  deptName: '图标验收',
                  businessId: '111',
                },
              ],
            },
            {
              deptName: '共享工作区',
              businessId: '12',
              children: [
                {
                  deptName: '学生成绩',
                  businessId: '122',
                },
              ],
            },
          ],
        },
      ],
    },
    required: true,
  },
  {
    field: 'fileMethods',
    label: '导入文件选择',
    slot: 'fileMethods',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'fileRename',
    label: '文件重名',
    component: 'RadioGroup',
    required: true,
    defaultValue: '3',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '全部放弃', value: '1' },
        { label: '全部替换', value: '2' },
        { label: '自动重命名', value: '3' },
      ],
    },
  },
];
export const MoveFormSchema: any[] = [
  {
    field: 'taskId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      // border: 'none',
      fieldNames: {
        label: 'workSpaceName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
];
export const formSchemaNewFolder: any = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    componentProps: {
      fieldNames: {
        label: 'workSpaceName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },

  {
    field: 'name',
    label: '文件夹名称',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文件夹名称',
    },
  },
  // {
  //   field: 'fileType',
  //   label: '权限模式',
  //   component: 'RadioGroup',
  //   defaultValue: '本级定义',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     options: [
  //       { label: '本级定义', value: '本级定义' },
  //       { label: '资源自定义', value: '资源自定义' },
  //     ],
  //     placeholder: '输入描述',
  //   },
  // },
  // {
  //   field: 'group',
  //   label: '权属工作组',
  //   component: 'Select',
  //   defaultValue: '默认工作组',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     placeholder: '输入描述',
  //     options: [{ label: '默认工作组', value: '默认工作组' }],
  //   },
  // },
];
export const isCustomSQLColumns: BasicColumn[] = [
  {
    title: '列名',
    dataIndex: 'fieldName',
  },
  {
    title: '类型',
    dataIndex: 'fieldType',
  },
];
export const notCustomSQLColumns: BasicColumn[] = [
  {
    title: '列名',
    dataIndex: 'fieldName',
  },
  {
    title: '类型',
    dataIndex: 'fieldType',
  },
  {
    title: '数据转换',
    dataIndex: 'dataConversion',
    slots: { customRender: 'dataConversion' },
  },
];
export const mappingRuleConfigurationColumns: BasicColumn[] = [
  {
    title: '规则名称',
    dataIndex: 'ruleName',
    width: 120,
    edit: true,
    editable: true,
    editComponent: 'Input',
  },
  {
    title: '规则类型',
    dataIndex: 'ruleType',
    width: 100,
  },
  {
    title: '数据表',
    dataIndex: 'dataTable',
    width: 120,
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        { label: '数据表1', value: '数据表1' },
        { label: '数据表2', value: '数据表2' },
      ],
    },
  },
  {
    title: '规则详情',
    dataIndex: 'ruleDetail',
    width: 200,
    slots: { customRender: 'ruleDetail' },
  },
  {
    title: '执行顺序',
    width: 50,
    dataIndex: 'executionSequence',
    slots: { customRender: 'executionSequence' },
  },
];
export const mappingRuleConfigurationFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    labelWidth: 20,
    componentProps: {
      placeholder: '输入关键字搜索',
    },
    component: 'Input',
    colProps: { span: 4 },
  },
  {
    field: 'ruleType',
    label: ' ',
    labelWidth: 20,
    componentProps: {
      placeholder: '规则类型',
      options: [
        { label: '数据操作过滤', value: '1' },
        { label: '数据值过滤', value: '2' },
        { label: '字段过滤', value: '3' },
      ],
    },
    component: 'Select',
    colProps: { span: 4 },
  },
  {
    field: 'deleteBtn',
    label: '',
    slot: 'deleteBtn',
  },
];
export const dataDirectionColumns: BasicColumn[] = [
  {
    title: '源库',
    dataIndex: 'dataBaseSource',
    width: 120,
  },
  {
    title: '目标库',
    dataIndex: 'dataBaseDirection',
    width: 120,
  },
];
export const dataDirectionFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    labelWidth: 20,
    componentProps: {
      placeholder: '输入关键字搜索',
    },
    component: 'Input',
    colProps: { span: 4 },
  },
];
export const getMetadataColumns: BasicColumn[] = [
  {
    title: '数据库',
    dataIndex: 'dataBase',
    width: 80,
  },
  {
    title: '表名',
    dataIndex: 'tableName',
    width: 120,
  },
];
export const tableDetailColumns: BasicColumn[] = [
  {
    title: '列名',
    dataIndex: 'name',
    width: 80,
  },
  {
    title: '详情',
    dataIndex: 'detail',
    width: 120,
  },
];
export const tableDetailFormSchema: FormSchema[] = [
  {
    field: 'tableName',
    label: '',
    component: 'Select',
    defaultValue: '1',
    componentProps: {
      showArrow: true,
      mode: 'multiple',
      options: [
        { label: 'id', value: '1' },
        { label: 'name', value: '2' },
        { label: 'age', value: '3' },
        { label: 'address', value: '4' },
      ],
    },
    colProps: { lg: 12, md: 12 },
  },
];
export const sourceSideConfigurationFormSchema: FormSchema[] = [
  {
    field: 'sourceType',
    label: '源端类型',
    component: 'Select',
    required: true,
    componentProps: {
      placeholder: '请选择源端类型',
      options: [
        { label: 'MYSQL', value: '1' },
        { label: 'ORACLE', value: '2' },
        { label: 'KUNDB', value: '3' },
      ],
    },
  },
  {
    field: 'analysisType',
    label: ' ',
    component: 'Select',
    componentProps: {
      options: [
        { label: '本地解析', value: '1' },
        { label: 'Xstream', value: '2' },
      ],
    },
    ifShow: ({ model }) => model.sourceType === '2',
  },
  {
    field: 'version',
    label: ' ',
    component: 'Select',
    componentProps: {
      options: [
        { label: '高可用版本', value: '1' },
        { label: '分布式版本', value: '2' },
      ],
    },
    ifShow: ({ model }) => model.sourceType === '3',
  },
  {
    field: 'analysisAlter1',
    label: '',
    slot: 'analysisAlter1',
    ifShow: ({ model }) => model.sourceType === '2' && model.analysisType === '1',
  },
  {
    field: 'analysisAlter2',
    label: '',
    slot: 'analysisAlter2',
    ifShow: ({ model }) => model.sourceType === '2' && model.analysisType === '2',
  },
  {
    field: 'RpcIp1',
    label: 'Rpc地址',
    component: 'Input',
    ifShow: ({ model }) => model.sourceType === '2' && model.analysisType === '1',
  },
  {
    field: 'RpcIp2',
    label: 'Rpc地址',
    component: 'Input',
    ifShow: ({ model }) => model.sourceType === '3' && model.version === '2',
  },
  {
    field: 'mysqlServer',
    label: 'MYSQL server',
    component: 'Input',
    ifShow: ({ model }) => model.sourceType === '3' && model.version === '1',
  },
  {
    field: 'dataSource',
    label: '数据源',
    component: 'Select',
    required: true,
    componentProps: {
      placeholder: '请选择数据源',
      options: [
        { label: 'KunDB数据源', value: '1' },
        { label: 'MongoDB数据源', value: '2' },
        { label: 'AmazonS3', value: '3' },
      ],
    },
  },
  {
    field: 'dataBase',
    label: '数据库',
    component: 'Select',
    componentProps: {
      mode: 'multiple',
      placeholder: '请选择数据源',
      options: [
        { label: 'KunDB', value: '1' },
        { label: 'MongoDB', value: '2' },
        { label: 'AmazonS3DB', value: '3' },
      ],
    },
  },
  {
    field: 'xstreaName',
    label: 'xstream服务名称',
    component: 'Input',
    required: true,
    ifShow: ({ model }) => model.sourceType === '2' && model.analysisType === '2',
  },
  {
    field: 'loadType',
    label: '数据表获取方式',
    component: 'RadioGroup',
    defaultValue: '1',
    componentProps: {
      options: [
        { label: '直接选表', value: '1' },
        { label: '规则过滤', value: '2' },
      ],
    },
  },
  {
    field: 'include',
    label: '包含',
    component: 'InputTextArea',
    ifShow: ({ model }) => model.loadType === '2',
  },
  {
    field: 'exclude',
    label: '排除',
    component: 'InputTextArea',
    ifShow: ({ model }) => model.loadType === '2',
  },
  {
    field: 'getMetadata',
    label: ' ',
    slot: 'getMetadata',
    ifShow: ({ model }) => model.loadType === '1',
  },
  {
    field: 'previewMetadata',
    label: ' ',
    slot: 'previewMetadata',
    ifShow: ({ model }) => model.loadType === '2',
  },
];
export const kafkaOptionsColumns: BasicColumn[] = [
  {
    title: '',
    editable: true,
    edit: true,
    dataIndex: 'name',
    width: 120,
  },
];
export const kafkaOptionsFormSchema: FormSchema[] = [
  {
    field: 'kafkaOptions1',
    label: '',
    slot: 'kafkaOptions1',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'topicType',
    label: 'Topic配置方式',
    component: 'RadioGroup',
    defaultValue: '1',
    required: true,
    componentProps: {
      options: [{ label: '自定义数量', value: '1' }],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'kafkaOptions2',
    label: '',
    slot: 'kafkaOptions2',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'num',
    label: 'Topic数量',
    component: 'InputNumber',
    componentProps: {
      min: 1,
      max: 50,
    },
    defaultValue: 3,
    required: true,
    colProps: { lg: 4, md: 4 },
  },
  {
    field: 'kafkaOptionsGenerate',
    label: '',
    slot: 'kafkaOptionsGenerate',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'kafkaOptions3',
    label: '',
    slot: 'kafkaOptions3',
    colProps: { lg: 24, md: 24 },
  },
];
export const mappingRulesTopicTableColumns: BasicColumn[] = [
  {
    title: 'Topic',
    dataIndex: 'name',
    width: 140,
  },
  {
    title: 'Db',
    dataIndex: 'dataBase',
    width: 120,
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      maxTagCount: 1,
      showArrow: true,
      mode: 'multiple',
      options: [
        { label: '请选择', value: '' },
        { label: 'fbs_1_flashsyncA_stable3.flashsync_stable1', value: '1' },
        { label: 'fbs_1_flashsyncA_stable3.flashsync_stable2', value: '2' },
      ],
    },
  },
  {
    title: 'Table名称表达式',
    dataIndex: 'remark',
    width: 100,
    edit: true,
    editable: true,
  },
];
export const mappingRulesTableColumns: BasicColumn[] = [
  {
    title: '源表名',
    dataIndex: 'dataSourceName',
    width: 120,
  },
  {
    title: 'Topic名称',
    dataIndex: 'topicName',
    width: 120,
  },
];
export const mappingRulesTableFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    labelWidth: 20,
    componentProps: {
      placeholder: '输入关键字搜索',
    },
    component: 'Input',
    colProps: { span: 6 },
  },
];
export const tableMappingFormSchema: FormSchema[] = [
  {
    field: 'dataSource',
    label: '目标数据源',
    component: 'Select',
    componentProps: {
      placeholder: '请选择数据源',
      options: [
        { label: 'KunDB', value: '1' },
        { label: 'MongoDB', value: '2' },
        { label: 'AmazonS3DB', value: '3' },
      ],
    },
    required: true,
  },
];
export const tableMappingColumns: BasicColumn[] = [
  {
    title: '规则名称',
    dataIndex: 'name',
    width: 140,
  },
  {
    title: '执行顺序',
    width: 50,
    dataIndex: 'executionSequence',
    slots: { customRender: 'executionSequence' },
  },
];
export const writePolicyColumns: BasicColumn[] = [
  {
    title: 'Topic名称',
    dataIndex: 'topicName',
    width: 120,
  },
  {
    title: '表数量',
    dataIndex: 'tableNum',
    width: 120,
  },
  {
    title: '并发数',
    dataIndex: 'concurrency',
    edit: true,
    editable: true,
    width: 120,
  },
  {
    title: '写入策略条数',
    dataIndex: 'num',
    edit: true,
    editable: true,
    width: 120,
  },
  {
    title: '时间间隔/s',
    dataIndex: 'timeInterval',
    edit: true,
    editable: true,
    width: 120,
  },
];
export const policyOptionFormSchema: FormSchema[] = [
  {
    field: 'policyOption',
    label: '',
    slot: 'policyOption',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'ddl',
    label: 'ddl变更策略',
    component: 'Select',
    defaultValue: '1',
    componentProps: {
      options: [{ label: 'DB-DB源端DDL处理默认策略', value: '1' }],
    },
  },
  {
    field: 'data',
    label: '数据积压策略',
    component: 'Select',
    defaultValue: '1',
    componentProps: {
      options: [{ label: '数据积压默认策略', value: '1' }],
    },
  },
  {
    field: 'exception',
    label: '数据异常策略',
    component: 'Select',
    defaultValue: '1',
    componentProps: {
      options: [{ label: '目标端数据异常默认策略', value: '1' }],
    },
  },
  {
    field: 'system',
    label: '系统异常策略',
    component: 'Select',
    defaultValue: '1',
    componentProps: {
      options: [{ label: '系统异常默认策略', value: '1' }],
    },
  },
  {
    field: 'config',
    label: '一致性检查策略',
    component: 'Select',
    defaultValue: '1',
    componentProps: {
      options: [{ label: '一致性检查默认策略', value: '1' }],
    },
  },
];
export const serverOptionsFormSchema: FormSchema[] = [
  {
    field: 'type',
    label: '存储格式',
    component: 'Select',
    defaultValue: '1',
    componentProps: {
      options: [{ label: 'JSON', value: '1' }],
    },
    colProps: { lg: 6, md: 6 },
  },
];
export const serverSourceOptionsColumns: BasicColumn[] = [
  {
    title: 'Key',
    dataIndex: 'keyData',
    edit: true,
    editable: true,
    width: 120,
  },
  {
    title: 'Value',
    dataIndex: 'valueData',
    edit: true,
    editable: true,
    width: 120,
  },
];
export const addBaseRulesSchema: FormSchema[] = [
  {
    field: 'name',
    label: '规则名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'loadType',
    label: '规则类型',
    component: 'RadioGroup',
    defaultValue: '1',
    componentProps: {
      options: [
        { label: '批量映射数据库', value: '1' },
        { label: '自定义库名映射规则', value: '2' },
      ],
    },
  },
  {
    field: 'range',
    label: '作用范围',
    component: 'RadioGroup',
    defaultValue: '1',
    componentProps: {
      options: [
        { label: '全局', value: '1' },
        { label: '自定义范围', value: '2' },
      ],
    },
    ifShow: ({ model }) => model.loadType === '2',
  },
  {
    field: 'choseTable',
    label: '',
    slot: 'choseTable',
    ifShow: ({ model }) => model.loadType === '2' && model.range === '2',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'prefix',
    label: '添加前缀',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    ifShow: ({ model }) => model.loadType === '2',
  },
  {
    field: 'suffix',
    label: '添加后缀',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    ifShow: ({ model }) => model.loadType === '2',
  },
  {
    field: 'change',
    label: '替换',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
    ifShow: ({ model }) => model.loadType === '2',
  },
  {
    field: 'onChange',
    label: '替换为',
    component: 'Input',
    labelWidth: 50,
    colProps: { lg: 12, md: 12 },
    ifShow: ({ model }) => model.loadType === '2',
  },
  {
    field: 'tableName',
    label: '',
    slot: 'tableName',
    ifShow: ({ model }) => model.loadType === '1',
    colProps: { lg: 24, md: 24 },
  },
];
export const addBaseRulesColumns: BasicColumn[] = [
  {
    title: '源库',
    dataIndex: 'dataSource',
    width: 120,
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        { label: 'fbs_1_flashsyncA_stable3.flashsync_stable1', value: '1' },
        { label: 'fbs_1_flashsyncA_stable3.flashsync_stable2', value: '2' },
      ],
    },
  },
  {
    title: '目标库',
    dataIndex: 'dataTopic',
    width: 120,
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        { label: 'fbs_1_flashsyncA_stable3.flashsync_stable1', value: '1' },
        { label: 'fbs_1_flashsyncA_stable3.flashsync_stable2', value: '2' },
      ],
    },
  },
];
export const addBaseRulesChoseTableColumns: BasicColumn[] = [
  {
    title: '源库',
    dataIndex: 'dataSource',
    width: 120,
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        { label: 'fbs_1_flashsyncA_stable3.flashsync_stable1', value: '1' },
        { label: 'fbs_1_flashsyncA_stable3.flashsync_stable2', value: '2' },
      ],
    },
  },
];
export const addFieldRulesSchema: FormSchema[] = [
  {
    field: 'name',
    label: '规则名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'range',
    label: '作用范围',
    component: 'RadioGroup',
    defaultValue: '1',
    componentProps: {
      options: [
        { label: '全局', value: '1' },
        { label: '自定义范围', value: '2' },
      ],
    },
  },
  {
    field: 'addField',
    label: '',
    slot: 'addField',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'choseTable',
    label: '',
    slot: 'choseTable',
    ifShow: ({ model }) => model.range === '2',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'prefix',
    label: '添加前缀',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'suffix',
    label: '添加后缀',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'change',
    label: '替换',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'onChange',
    label: '替换为',
    component: 'Input',
    labelWidth: 50,
    colProps: { lg: 12, md: 12 },
  },
];
export const addTableRulesSchema: FormSchema[] = [
  {
    field: 'name',
    label: '规则名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'range',
    label: '作用范围',
    component: 'RadioGroup',
    defaultValue: '1',
    componentProps: {
      options: [
        { label: '全局', value: '1' },
        { label: '自定义范围', value: '2' },
      ],
    },
  },
  {
    field: 'choseTable',
    label: '',
    slot: 'choseTable',
    ifShow: ({ model }) => model.range === '2',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'prefix',
    label: '添加前缀',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'suffix',
    label: '添加后缀',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'change',
    label: '替换',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'onChange',
    label: '替换为',
    component: 'Input',
    labelWidth: 50,
    colProps: { lg: 12, md: 12 },
  },
];
export const fieldMappingColumns: BasicColumn[] = [
  {
    title: '规则名称',
    dataIndex: 'name',
    width: 140,
  },
  {
    title: '规则类型',
    dataIndex: 'type',
    width: 140,
  },
  {
    title: '执行顺序',
    width: 50,
    dataIndex: 'executionSequence',
    slots: { customRender: 'executionSequence' },
  },
];
export const addFieldRulesColumns: BasicColumn[] = [
  {
    title: '字段名',
    dataIndex: 'name',
    width: 120,
    edit: true,
    editable: true,
  },
  {
    title: '字段类型',
    dataIndex: 'type',
    width: 120,
    edit: true,
    editable: true,
  },
  {
    title: '默认值',
    dataIndex: 'defaultValue',
    width: 120,
    edit: true,
    editable: true,
  },
];
export const fieldMappingFormSchema: FormSchema[] = [
  {
    field: 'sourceTable',
    label: ' ',
    component: 'Select',
    defaultValue: 'GXXADMIN',
    componentProps: {
      options: [
        { label: 'GXXADMIN', value: 'GXXADMIN' },
        { label: 'GXX_ADMIN', value: 'GXX_ADMIN' },
        { label: 'GXX_ADMIN_1', value: 'GXX_ADMIN_1' },
      ],
    },
    colProps: { lg: 6, md: 6 },
  },
  {
    field: 'topicTable',
    label: ' ',
    component: 'Select',
    defaultValue: 'FLASH_ORCL',
    componentProps: {
      options: [
        { label: 'FLASH_ORCL', value: 'FLASH_ORCL' },
        { label: 'FLASH_ORCL_1', value: 'FLASH_ORCL_1' },
        { label: 'FLASH_ORCL_2', value: 'FLASH_ORCL_2' },
      ],
    },
    colProps: { lg: 6, md: 6 },
  },
];
export const fieldMappingRulesTableColumns: BasicColumn[] = [
  {
    title: '源表字段名',
    dataIndex: 'dataSourceName',
    width: 120,
  },
  {
    title: '目标表字段名',
    dataIndex: 'topicName',
    width: 120,
  },
];
export const messageFormSchema: FormSchema[] = [
  {
    field: 'type',
    label: '是否保存schema版本',
    component: 'Switch',
    colProps: { lg: 6, md: 6 },
  },
];
export const versionManagementFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    componentProps: {
      placeholder: '输入关键字搜索',
    },
    component: 'Input',
    colProps: { span: 6 },
  },
];
export const startSchema: FormSchema[] = [
  {
    field: 'isVertical',
    label: '是否垂直同步点',
    component: 'RadioGroup',
    defaultValue: '1',
    componentProps: {
      options: [
        { label: '是', value: '1' },
        { label: '否', value: '2' },
      ],
    },
  },
  {
    field: 'alter',
    label: '',
    slot: 'alter',
    colProps: { lg: 24, md: 24 },
    ifShow: ({ model }) => model.isVertical === '1',
  },
  {
    field: 'type',
    label: ' ',
    component: 'RadioGroup',
    defaultValue: '1',
    componentProps: {
      options: [
        { label: '指定日志文件', value: '1' },
        { label: '指定同步点', value: '2' },
      ],
    },
    colProps: { lg: 24, md: 24 },
    ifShow: ({ model }) => model.isVertical === '1',
  },
  {
    field: 'name',
    label: '文件名称',
    component: 'Input',
    required: true,
    colProps: { lg: 24, md: 24 },
    ifShow: ({ model }) => model.isVertical === '1' && model.type === '1',
  },
  {
    field: 'position',
    label: '位点',
    component: 'Input',
    required: true,
    colProps: { lg: 24, md: 24 },
    ifShow: ({ model }) => model.isVertical === '1' && model.type === '1',
  },
  {
    field: 'point',
    label: '同步点',
    component: 'Select',
    componentProps: {
      options: [
        { label: '2024-01-01 12:22:33', value: '2024-01-01 12:22:33' },
        { label: '2024-01-02 15:23:13', value: '2024-01-02 15:23:13' },
        { label: '2024-01-03 16:24:14', value: '2024-01-03 16:24:14' },
        { label: '2024-01-04 17:25:15', value: '2024-01-04 17:25:15' },
      ],
    },
    colProps: { lg: 24, md: 24 },
    ifShow: ({ model }) => model.isVertical === '1' && model.type === '2',
  },
];
